@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List, Union
+from typing import Any, Dict, List, Mapping, Sequence, Union
 
 from .literals import (
     ApplicationRevisionSortByType,
@@ -201,8 +201,8 @@ __all__ = (
 AddTagsToOnPremisesInstancesInputRequestTypeDef = TypedDict(
     "AddTagsToOnPremisesInstancesInputRequestTypeDef",
     {
-        "tags": List["TagTypeDef"],
-        "instanceNames": List[str],
+        "tags": Sequence["TagTypeDef"],
+        "instanceNames": Sequence[str],
     },
 )
 
@@ -268,7 +268,7 @@ BatchGetApplicationRevisionsInputRequestTypeDef = TypedDict(
     "BatchGetApplicationRevisionsInputRequestTypeDef",
     {
         "applicationName": str,
-        "revisions": List["RevisionLocationTypeDef"],
+        "revisions": Sequence["RevisionLocationTypeDef"],
     },
 )
 
@@ -285,7 +285,7 @@ BatchGetApplicationRevisionsOutputTypeDef = TypedDict(
 BatchGetApplicationsInputRequestTypeDef = TypedDict(
     "BatchGetApplicationsInputRequestTypeDef",
     {
-        "applicationNames": List[str],
+        "applicationNames": Sequence[str],
     },
 )
 
@@ -301,7 +301,7 @@ BatchGetDeploymentGroupsInputRequestTypeDef = TypedDict(
     "BatchGetDeploymentGroupsInputRequestTypeDef",
     {
         "applicationName": str,
-        "deploymentGroupNames": List[str],
+        "deploymentGroupNames": Sequence[str],
     },
 )
 
@@ -318,7 +318,7 @@ BatchGetDeploymentInstancesInputRequestTypeDef = TypedDict(
     "BatchGetDeploymentInstancesInputRequestTypeDef",
     {
         "deploymentId": str,
-        "instanceIds": List[str],
+        "instanceIds": Sequence[str],
     },
 )
 
@@ -335,7 +335,7 @@ BatchGetDeploymentTargetsInputRequestTypeDef = TypedDict(
     "BatchGetDeploymentTargetsInputRequestTypeDef",
     {
         "deploymentId": str,
-        "targetIds": List[str],
+        "targetIds": Sequence[str],
     },
     total=False,
 )
@@ -351,7 +351,7 @@ BatchGetDeploymentTargetsOutputTypeDef = TypedDict(
 BatchGetDeploymentsInputRequestTypeDef = TypedDict(
     "BatchGetDeploymentsInputRequestTypeDef",
     {
-        "deploymentIds": List[str],
+        "deploymentIds": Sequence[str],
     },
 )
 
@@ -366,7 +366,7 @@ BatchGetDeploymentsOutputTypeDef = TypedDict(
 BatchGetOnPremisesInstancesInputRequestTypeDef = TypedDict(
     "BatchGetOnPremisesInstancesInputRequestTypeDef",
     {
-        "instanceNames": List[str],
+        "instanceNames": Sequence[str],
     },
 )
 
@@ -430,7 +430,7 @@ _OptionalCreateApplicationInputRequestTypeDef = TypedDict(
     "_OptionalCreateApplicationInputRequestTypeDef",
     {
         "computePlatform": ComputePlatformType,
-        "tags": List["TagTypeDef"],
+        "tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -494,10 +494,10 @@ _OptionalCreateDeploymentGroupInputRequestTypeDef = TypedDict(
     "_OptionalCreateDeploymentGroupInputRequestTypeDef",
     {
         "deploymentConfigName": str,
-        "ec2TagFilters": List["EC2TagFilterTypeDef"],
-        "onPremisesInstanceTagFilters": List["TagFilterTypeDef"],
-        "autoScalingGroups": List[str],
-        "triggerConfigurations": List["TriggerConfigTypeDef"],
+        "ec2TagFilters": Sequence["EC2TagFilterTypeDef"],
+        "onPremisesInstanceTagFilters": Sequence["TagFilterTypeDef"],
+        "autoScalingGroups": Sequence[str],
+        "triggerConfigurations": Sequence["TriggerConfigTypeDef"],
         "alarmConfiguration": "AlarmConfigurationTypeDef",
         "autoRollbackConfiguration": "AutoRollbackConfigurationTypeDef",
         "outdatedInstancesStrategy": OutdatedInstancesStrategyType,
@@ -505,9 +505,9 @@ _OptionalCreateDeploymentGroupInputRequestTypeDef = TypedDict(
         "blueGreenDeploymentConfiguration": "BlueGreenDeploymentConfigurationTypeDef",
         "loadBalancerInfo": "LoadBalancerInfoTypeDef",
         "ec2TagSet": "EC2TagSetTypeDef",
-        "ecsServices": List["ECSServiceTypeDef"],
+        "ecsServices": Sequence["ECSServiceTypeDef"],
         "onPremisesTagSet": "OnPremisesTagSetTypeDef",
-        "tags": List["TagTypeDef"],
+        "tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -1189,8 +1189,8 @@ _OptionalListDeploymentInstancesInputRequestTypeDef = TypedDict(
     "_OptionalListDeploymentInstancesInputRequestTypeDef",
     {
         "nextToken": str,
-        "instanceStatusFilter": List[InstanceStatusType],
-        "instanceTypeFilter": List[InstanceTypeType],
+        "instanceStatusFilter": Sequence[InstanceStatusType],
+        "instanceTypeFilter": Sequence[InstanceTypeType],
     },
     total=False,
 )
@@ -1217,7 +1217,7 @@ ListDeploymentTargetsInputRequestTypeDef = TypedDict(
     {
         "deploymentId": str,
         "nextToken": str,
-        "targetFilters": Dict[TargetFilterNameType, List[str]],
+        "targetFilters": Mapping[TargetFilterNameType, Sequence[str]],
     },
     total=False,
 )
@@ -1237,7 +1237,7 @@ ListDeploymentsInputRequestTypeDef = TypedDict(
         "applicationName": str,
         "deploymentGroupName": str,
         "externalId": str,
-        "includeOnlyStatuses": List[DeploymentStatusType],
+        "includeOnlyStatuses": Sequence[DeploymentStatusType],
         "createTimeRange": "TimeRangeTypeDef",
         "nextToken": str,
     },
@@ -1274,7 +1274,7 @@ ListOnPremisesInstancesInputRequestTypeDef = TypedDict(
     "ListOnPremisesInstancesInputRequestTypeDef",
     {
         "registrationStatus": RegistrationStatusType,
-        "tagFilters": List["TagFilterTypeDef"],
+        "tagFilters": Sequence["TagFilterTypeDef"],
         "nextToken": str,
     },
     total=False,
@@ -1441,8 +1441,8 @@ RelatedDeploymentsTypeDef = TypedDict(
 RemoveTagsFromOnPremisesInstancesInputRequestTypeDef = TypedDict(
     "RemoveTagsFromOnPremisesInstancesInputRequestTypeDef",
     {
-        "tags": List["TagTypeDef"],
-        "instanceNames": List[str],
+        "tags": Sequence["TagTypeDef"],
+        "instanceNames": Sequence[str],
     },
 )
 
@@ -1552,7 +1552,7 @@ TagResourceInputRequestTypeDef = TypedDict(
     "TagResourceInputRequestTypeDef",
     {
         "ResourceArn": str,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
 )
 
@@ -1652,7 +1652,7 @@ UntagResourceInputRequestTypeDef = TypedDict(
     "UntagResourceInputRequestTypeDef",
     {
         "ResourceArn": str,
-        "TagKeys": List[str],
+        "TagKeys": Sequence[str],
     },
 )
 
@@ -1677,11 +1677,11 @@ _OptionalUpdateDeploymentGroupInputRequestTypeDef = TypedDict(
     {
         "newDeploymentGroupName": str,
         "deploymentConfigName": str,
-        "ec2TagFilters": List["EC2TagFilterTypeDef"],
-        "onPremisesInstanceTagFilters": List["TagFilterTypeDef"],
-        "autoScalingGroups": List[str],
+        "ec2TagFilters": Sequence["EC2TagFilterTypeDef"],
+        "onPremisesInstanceTagFilters": Sequence["TagFilterTypeDef"],
+        "autoScalingGroups": Sequence[str],
         "serviceRoleArn": str,
-        "triggerConfigurations": List["TriggerConfigTypeDef"],
+        "triggerConfigurations": Sequence["TriggerConfigTypeDef"],
         "alarmConfiguration": "AlarmConfigurationTypeDef",
         "autoRollbackConfiguration": "AutoRollbackConfigurationTypeDef",
         "outdatedInstancesStrategy": OutdatedInstancesStrategyType,
@@ -1689,7 +1689,7 @@ _OptionalUpdateDeploymentGroupInputRequestTypeDef = TypedDict(
         "blueGreenDeploymentConfiguration": "BlueGreenDeploymentConfigurationTypeDef",
         "loadBalancerInfo": "LoadBalancerInfoTypeDef",
         "ec2TagSet": "EC2TagSetTypeDef",
-        "ecsServices": List["ECSServiceTypeDef"],
+        "ecsServices": Sequence["ECSServiceTypeDef"],
         "onPremisesTagSet": "OnPremisesTagSetTypeDef",
     },
     total=False,
